From c9192944cf649fdbafce6e65ac66ece45f0f68fd Mon Sep 17 00:00:00 2001
From: Merlijn Wajer <merlijn@wizzup.org>
Date: Sun, 17 May 2020 13:21:12 +0200
Subject: [PATCH 1/2] HACK: korad-kaxxxxp: support VELLEMAN_LABPS3005DN
 (QJE3005PV1.0)

This will likely break all other devices, since the protocol looks
different.
---
 src/hardware/korad-kaxxxxp/api.c      |  2 ++
 src/hardware/korad-kaxxxxp/protocol.c | 13 +++++++++++--
 src/hardware/korad-kaxxxxp/protocol.h |  1 +
 3 files changed, 14 insertions(+), 2 deletions(-)

diff --git a/src/hardware/korad-kaxxxxp/api.c b/src/hardware/korad-kaxxxxp/api.c
index 21ab6844..5888ef7e 100644
--- a/src/hardware/korad-kaxxxxp/api.c
+++ b/src/hardware/korad-kaxxxxp/api.c
@@ -82,6 +82,8 @@ static const struct korad_kaxxxxp_model models[] = {
 		"S-LS-31 V2.0", 1, {0, 31, 0.01}, {0, 5.1, 0.001}},
 	{KORAD_KD6005P, "Korad", "KD6005P",
 		"KORAD KD6005P V2.2", 1, {0, 61, 0.01}, {0, 5.1, 0.001}},
+	{VELLEMAN_LABPS3005DN, "Velleman", "PS3005DN",
+		"QJE3005PV1.0", 1, {0, 31, 0.01}, {0, 5.1, 0.001}},
 	ALL_ZERO
 };
 
diff --git a/src/hardware/korad-kaxxxxp/protocol.c b/src/hardware/korad-kaxxxxp/protocol.c
index 848279d7..bbcd2990 100644
--- a/src/hardware/korad-kaxxxxp/protocol.c
+++ b/src/hardware/korad-kaxxxxp/protocol.c
@@ -29,11 +29,15 @@ SR_PRIV int korad_kaxxxxp_send_cmd(struct sr_serial_dev_inst *serial,
 {
 	int ret;
 
+	char* newcmd = g_strconcat(cmd, "\\n", NULL);
+
 	sr_dbg("Sending '%s'.", cmd);
-	if ((ret = serial_write_blocking(serial, cmd, strlen(cmd), 0)) < 0) {
+	if ((ret = serial_write_blocking(serial, newcmd, strlen(newcmd), 0)) < 0) {
 		sr_err("Error sending command: %d.", ret);
+		free(newcmd);
 		return ret;
 	}
+	free(newcmd);
 
 	return ret;
 }
@@ -60,6 +64,11 @@ SR_PRIV int korad_kaxxxxp_read_chars(struct sr_serial_dev_inst *serial,
 
 	buf[count] = 0;
 
+	int len = strlen(buf);
+	if (buf[len-1] == '\n') {
+		buf[len-1] = 0;
+	}
+
 	sr_spew("Received: '%s'.", buf);
 
 	return ret;
@@ -105,7 +114,7 @@ SR_PRIV int korad_kaxxxxp_set_value(struct sr_serial_dev_inst *serial,
 		value = devc->set_voltage_target;
 		break;
 	case KAXXXXP_OUTPUT:
-		cmd = "OUT%01.0f";
+		cmd = "OUTPUT%01.0f";
 		value = (devc->set_output_enabled) ? 1 : 0;
 		/* Set value back to recognize changes */
 		devc->output_enabled = devc->set_output_enabled;
diff --git a/src/hardware/korad-kaxxxxp/protocol.h b/src/hardware/korad-kaxxxxp/protocol.h
index ea28a71c..9c83625b 100644
--- a/src/hardware/korad-kaxxxxp/protocol.h
+++ b/src/hardware/korad-kaxxxxp/protocol.h
@@ -49,6 +49,7 @@ enum {
 	TENMA_72_2535_V21,
 	STAMOS_SLS31_V20,
 	KORAD_KD6005P,
+	VELLEMAN_LABPS3005DN,
 	/* Support for future devices with this protocol. */
 };
 
-- 
2.24.1

